package de.intevation.flys.artifacts.states;

import org.apache.log4j.Logger;

import org.w3c.dom.Element;

import de.intevation.artifacts.CallContext;

import de.intevation.artifacts.common.utils.XMLUtils;

import de.intevation.artifactdatabase.ProtocolUtils;
import de.intevation.artifactdatabase.data.StateData;

import de.intevation.flys.artifacts.resources.Resources;

/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class LocationDistanceSelect extends DefaultState {

    /** The logger used in this class.*/
    private static Logger logger = Logger.getLogger(LocationDistanceSelect.class);


    /** The default step width.*/
    public static final String DEFAULT_STEP = "100";

    /**
     * The default constructor that initializes an empty State object.
     */
    public LocationDistanceSelect() {
    }

    protected Element createData(
        XMLUtils.ElementCreator cr,
        StateData   data,
        CallContext context)
    {
        Element select = ProtocolUtils.createArtNode(
            cr, "select", null, null);

        cr.addAttr(select, "name", data.getName(), true);

        Element label = ProtocolUtils.createArtNode(
            cr, "label", null, null);

        Element choices = ProtocolUtils.createArtNode(
            cr, "choices", null, null);

        label.setTextContent(Resources.getMsg(
            context.getMeta(),
            data.getName(),
            data.getName()));

        select.appendChild(label);

        return select;
    }


    protected Element[] createItems(
        XMLUtils.ElementCreator cr,
        String      name,
        CallContext context)
    {
        // TODO Insert correct min/max values!

        if (name.equals("ld_from")) {
            Element min = createItem(cr, new String[] {"min", "1"});
            return new Element[] { min };
        }
        else if (name.equals("ld_to")) {
            Element max = createItem(cr, new String[] {"max", "10"});
            return new Element[] { max };
        }
        else {
            Element step = createItem(cr, new String[] {"step", DEFAULT_STEP});
            return new Element[] { step };
        }

    }


    protected Element createItem(XMLUtils.ElementCreator cr, Object obj) {
        Element item  = ProtocolUtils.createArtNode(cr, "item", null, null);
        Element label = ProtocolUtils.createArtNode(cr, "label", null, null);
        Element value = ProtocolUtils.createArtNode(cr, "value", null, null);

        String[] arr = (String[]) obj;

        label.setTextContent(arr[0]);
        value.setTextContent(arr[1]);

        item.appendChild(label);
        item.appendChild(value);

        return item;
    }


    protected String getUIProvider() {
        return "location_distance_panel";
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
